/** @type {import('tailwindcss').Config} */

const path = require('path');
const plugin = require('tailwindcss/plugin');

const theme = require('./theme/main');

module.exports = {
	content: [
		path.resolve(__dirname + '/../../../**/*.{js,ts,tsx}'),
		path.resolve(__dirname + '/../../stories/**/*.mdx'),
		'!**/node_modules/**',
	],
	safelist: [
		{
			pattern: /col-/,
			variants: ['sm', 'md', 'lg', 'xl'],
		},
		{
			pattern: /grid/,
			variants: ['sm', 'md', 'lg', 'xl'],
		},
		{
			pattern: /gap/,
		},
		{
			pattern: /text-[\d]?xl/,
		},
		{
			pattern: /m[tlbrxy]?-\d/,
		},
	],
	theme: {
		extend: theme,
	},
	plugins: [
		plugin(require('./components/button')),
		plugin(require('./components/buttonGroup')),
		plugin(require('./components/field')),
		plugin(require('./components/message')),
		plugin(require('./components/skeleton')),
		plugin(require('./components/table')),
		plugin(require('./components/grid')),
		plugin(require('./components/list')),
		plugin(require('./components/modal')),
		plugin(require('./components/calendar')),
		plugin(require('./components/human')),
		plugin(require('./components/toaster')),
		function ({ addVariant }) {
			addVariant('child', '& > *');
		},
	],
	corePlugins: {
		float: false,
	},
};
